==> glbinding_2.1.1.orig.tar.gz: glbinding-2.1.1/source/glbinding/include/glbinding/gl31ext/types.h <==
#pragma once

#include <glbinding/nogl.h>
#include <glbinding/gl/types.h>


namespace gl31ext
{


using gl::GLextension;
using gl::GLenum;
using gl::GLboolean;
using gl::GLbitfield;
using gl::GLvoid;
using gl::GLbyte;
using gl::GLshort;
using gl::GLint;
using gl::GLclampx;
using gl::GLubyte;
using gl::GLushort;
using gl::GLuint;
using gl::GLsizei;
using gl::GLfloat;
using gl::GLclampf;
using gl::GLdouble;
using gl::GLclampd;
using gl::GLeglImageOES;
using gl::GLchar;
using gl::GLcharARB;
using gl::GLhandleARB;
using gl::GLhalfARB;
using gl::GLhalf;
using gl::GLfixed;
using gl::GLintptr;
using gl::GLsizeiptr;
using gl::GLint64;
using gl::GLuint64;
using gl::GLintptrARB;
using gl::GLsizeiptrARB;
using gl::GLint64EXT;
using gl::GLuint64EXT;
using gl::GLsync;
using gl::_cl_context;
using gl::_cl_event;
using gl::GLDEBUGPROC;
using gl::GLDEBUGPROCARB;
using gl::GLDEBUGPROCKHR;
using gl::GLDEBUGPROCAMD;
using gl::GLhalfNV;
using gl::GLvdpauSurfaceNV;
using gl::GLuint_array_2;
using gl::AttribMask;
using gl::ClearBufferMask;
using gl::ClientAttribMask;
using gl::ContextFlagMask;
using gl::ContextProfileMask;
using gl::FfdMaskSGIX;
using gl::FragmentShaderColorModMaskATI;
using gl::FragmentShaderDestMaskATI;
using gl::FragmentShaderDestModMaskATI;
using gl::MapBufferUsageMask;
using gl::MemoryBarrierMask;
using gl::PathRenderingMaskNV;
using gl::PerformanceQueryCapsMaskINTEL;
using gl::SyncObjectMask;
using gl::TextureStorageMaskAMD;
using gl::UseProgramStageMask;
using gl::VertexHintsMaskPGI;
using gl::UnusedMask;
using gl::BufferAccessMask;
using gl::BufferStorageMask;
using gl::PathFontStyle;


} // namespace gl31ext

==> glbinding_3.3.0.orig.tar.gz: glbinding-3.3.0/source/glbinding/include/glbinding/gl31ext/types.h <==

#pragma once


#include <glbinding/nogl.h>
#include <glbinding/gl/types.h>


namespace gl31ext
{



using gl::_cl_context;
using gl::_cl_event;
using gl::AttribMask;
using gl::BufferStorageMask;
using gl::ClearBufferMask;
using gl::ClientAttribMask;
using gl::ContextFlagMask;
using gl::ContextProfileMask;
using gl::FfdMaskSGIX;
using gl::FragmentShaderColorModMaskATI;
using gl::FragmentShaderDestMaskATI;
using gl::FragmentShaderDestModMaskATI;
using gl::GLbitfield;
using gl::GLboolean;
using gl::GLbyte;
using gl::GLchar;
using gl::GLcharARB;
using gl::GLclampd;
using gl::GLclampf;
using gl::GLclampx;
using gl::GLDEBUGPROC;
using gl::GLDEBUGPROCAMD;
using gl::GLDEBUGPROCARB;
using gl::GLDEBUGPROCKHR;
using gl::GLdouble;
using gl::GLeglClientBufferEXT;
using gl::GLeglImageOES;
using gl::GLenum;
using gl::GLextension;
using gl::GLfixed;
using gl::GLfloat;
using gl::GLhalf;
using gl::GLhalfARB;
using gl::GLhalfNV;
using gl::GLhandleARB;
using gl::GLint;
using gl::GLint64;
using gl::GLint64EXT;
using gl::GLintptr;
using gl::GLintptrARB;
using gl::GLshort;
using gl::GLsizei;
using gl::GLsizeiptr;
using gl::GLsizeiptrARB;
using gl::GLsync;
using gl::GLubyte;
using gl::GLuint;
using gl::GLuint64;
using gl::GLuint64EXT;
using gl::GLushort;
using gl::GLvdpauSurfaceNV;
using gl::GLvoid;
using gl::GLVULKANPROCNV;
using gl::MapBufferAccessMask;
using gl::MemoryBarrierMask;
using gl::OcclusionQueryEventMaskAMD;
using gl::PathFontStyle;
using gl::PathMetricMask;
using gl::PathRenderingMaskNV;
using gl::PerformanceQueryCapsMaskINTEL;
using gl::SyncObjectMask;
using gl::TextureStorageMaskAMD;
using gl::UnusedMask;
using gl::UseProgramStageMask;
using gl::VertexHintsMaskPGI;
using gl::VertexShaderWriteMaskEXT;


} // namespace gl31ext
